@@ -1,6 +1,8 @@
 from pathlib import Path
+from typing import List
 import os
 import json
+import logging
 
 
 class BadToken(Exception):
@@ -9,18 +11,16 @@ class BadToken(Exception):
 
 class DictFinder(object):
 
-    def __init__(self, introot:str, docroot:str, path:str, tokensname:str):
+    def __init__(self, docroot:str, path:str, tokensname:str):
         self._docroot = docroot
-        self._introot = introot
         self._path = path
         self._tokens_name = tokensname
 
     def get_tokens(self):
+        """ first checks "public", then other roots, last "internal". prefered in that order """
         pointer = os.path.join(self._docroot, self._path)
         tokens = dict()
         tokens = self._find_tokens( self._docroot, pointer, tokens)
-        pointer = os.path.join(self._introot, self._path)
-        tokens = self._find_tokens( self._introot, pointer, tokens)
         return tokens
 
     def _find_tokens( self, root:str, pointer:str, tokens:dict) -> dict:
@@ -40,5 +40,6 @@ class DictFinder(object):
             with open(path) as f:
                 return json.load(f)
         except FileNotFoundError as e:
+            logging.debug(f"DictFinder._read_json: no such file {path}. returning empty dict, as expected.")
             return dict()
 
